SoftDTW Subpackage — dtw_loss_functions documentation

# SoftDTW Subpackage

Since there are various implementations online of the SoftDTW, this subpackage was created to collect the different implementations.

Currently, the following implementations are available :

- pytorch-softdtw-cuda by Mehran Maghoumi [Mag20] [MTL21]

    - GitHub repository : https://github.com/Maghoumi/pytorch-softdtw-cuda

- pysdtw by Antoine Loriette

    - GitHub repository : https://github.com/toinsson/pysdtw

    - PyPi Page : https://pypi.org/project/pysdtw/

- sdtw-cuda-torch by BGU-CS-VIL (implemented by Ron Shapira Weber) [WF26] [SWBL+25]

    - GitHub repository : https://github.com/BGU-CS-VIL/sdtw-cuda-torch

If you use this module, please cite together with this package the original paper of the implementation you are using.

## Authors

Alberto Zancanaro <alberto.zancanaro@uni.lu>

SoftDTW Implementations

- SoftDTW (Mehran Maghoumi)
- pysdtw normalized
- SoftDTW (Ron Shapira Weber)